@@ -369,7 +369,7 @@ class WordType(models.Model):
         stresses = re.sub(r'\D',r'',guessed)
         syls = self.UR.filter(Syllabic=True)
         for i in range(len(syls)):
-            syls[i].Stressed = int(stressed[i])
+            syls[i].Stressed = int(stresses[i])
             syls[i].save()
             if syls[i].Stressed == 1:
                 self.StressVowel = str(syls[i].SegmentType)
