@@ -94,7 +94,7 @@ def basic(request):
         if request.method == 'POST':
             form = AnalysisForm(request.POST)
             if form.is_valid():
-                doBasicAnalysis.delay(form.cleaned_data)
+                doBasicAnalysis.delay(form)
                 return redirect(index)
         form = AnalysisForm()
         return render(request,'buckeyebrowser/form.html',{'form':form})
